@@ -1,14 +1,27 @@
-import click
+from typing import Any
 
+import click
+from click import UsageError
+
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
+from ggshield.core.errors import handle_exception
 from ggshield.core.git_shell import get_list_commit_SHA
-from ggshield.core.utils import ScanContext, ScanMode, handle_exception
+from ggshield.scan import ScanContext, ScanMode
 from ggshield.scan.repo import scan_commit_range
 
 
 @click.command()
 @click.argument("commit_range", nargs=1, type=click.STRING)
+@add_secret_scan_common_options()
 @click.pass_context
-def range_cmd(ctx: click.Context, commit_range: str) -> int:  # pragma: no cover
+def range_cmd(
+    ctx: click.Context,
+    commit_range: str,
+    **kwargs: Any,
+) -> int:  # pragma: no cover
     """
     scan a defined COMMIT_RANGE in git.
 
@@ -19,7 +32,7 @@ def range_cmd(ctx: click.Context, commit_range: str) -> int:  # pragma: no cover
     try:
         commit_list = get_list_commit_SHA(commit_range)
         if not commit_list:
-            raise click.ClickException("invalid commit range")
+            raise UsageError("invalid commit range")
         if config.verbose:
             click.echo(f"Commits to scan: {len(commit_list)}", err=True)
 
@@ -32,11 +45,12 @@ def range_cmd(ctx: click.Context, commit_range: str) -> int:  # pragma: no cover
             client=ctx.obj["client"],
             cache=ctx.obj["cache"],
             commit_list=commit_list,
-            output_handler=ctx.obj["output_handler"],
+            output_handler=create_output_handler(ctx),
             exclusion_regexes=ctx.obj["exclusion_regexes"],
             matches_ignore=config.secret.ignored_matches,
             scan_context=scan_context,
             ignored_detectors=config.secret.ignored_detectors,
+            ignore_known_secrets=config.ignore_known_secrets,
         )
     except Exception as error:
         return handle_exception(error, config.verbose)
