@@ -1,34 +1,11 @@
-from typing import cast
-
+import requests
 import urllib3
-from click import UsageError
 from pygitguardian import GGClient
-from pygitguardian.models import Detail
-from requests import Response, Session
+from requests import Session
 
 from .config import Config
-from .constants import DEFAULT_DASHBOARD_URL
-from .errors import UnexpectedError, UnknownInstanceError
-
-
-def load_detail(resp: Response) -> Detail:
-    """
-    load_detail loads a Detail from a response
-    be it JSON or html.
-
-    :param resp: API response
-    :type resp: Response
-    :return: detail object of response
-    :rtype: Detail
-    """
-    if resp.headers["content-type"] == "application/json":
-        data = resp.json()
-        if "detail" not in data:
-            data = {"detail": str(data)}
-    else:
-        data = {"detail": resp.text}
-
-    return cast(Detail, Detail.SCHEMA.load(data))
+from .constants import DEFAULT_INSTANCE_URL
+from .errors import APIKeyCheckError, UnexpectedError, UnknownInstanceError
 
 
 def create_client_from_config(config: Config) -> GGClient:
@@ -39,11 +16,22 @@ def create_client_from_config(config: Config) -> GGClient:
         api_key = config.api_key
         api_url = config.api_url
     except UnknownInstanceError as e:
-        if e.instance == DEFAULT_DASHBOARD_URL:
+        if e.instance == DEFAULT_INSTANCE_URL:
             # This can happen when the user first tries the app and has not gone through
             # the authentication procedure yet. In this case, replace the error message
             # complaining about an unknown instance with a more user-friendly one.
-            raise UsageError("GitGuardian API key is needed.")
+            raise APIKeyCheckError(
+                e.instance,
+                """A GitGuardian API key is needed to use ggshield.
+To get one, authenticate to your dashboard by running:
+
+    ggshield auth login
+
+If you are using an on-prem version of GitGuardian, \
+use the --instance option to point to it.
+Read the following documentation for more information: \
+https://docs.gitguardian.com/ggshield-docs/reference/auth/login""",
+            )
         else:
             raise
 
@@ -77,3 +65,31 @@ def create_session(allow_self_signed: bool = False) -> Session:
         urllib3.disable_warnings()
         session.verify = False
     return session
+
+
+def check_client_api_key(client: GGClient) -> None:
+    """
+    Raises APIKeyCheckError if the API key configured for the client is not usable
+    (either it is invalid or unset). Raises UnexpectedError if the API is down.
+    """
+    try:
+        response = client.health_check()
+    except requests.exceptions.ConnectionError as e:
+        raise UnexpectedError(
+            "Failed to connect to GitGuardian server. Check your"
+            f" instance URL settings.\nDetails: {e}."
+        )
+
+    if response.success:
+        return
+
+    if response.status_code == 401:
+        raise APIKeyCheckError(client.base_uri, "Invalid API key.")
+    elif response.status_code == 404:
+        raise UnexpectedError(
+            "The server returned a 404 error. Check your instance URL" " settings."
+        )
+    else:
+        raise UnexpectedError(
+            f"Server is not responding as expected.\nDetails: {response.detail}"
+        )
