@@ -9,6 +9,7 @@ from ggshield.core.config.utils import (
     ensure_path_exists,
     get_auth_config_filepath,
     load_yaml_dict,
+    replace_in_keys,
     save_yaml_dict,
 )
 from ggshield.core.dirs import get_config_dir
@@ -68,7 +69,10 @@ def prepare_auth_config_dict_for_parse(data: Dict[str, Any]) -> Dict[str, Any]:
     single instances[].account key.
 
     Stop if there is not exactly one account.
+
+    We replace `-` with `_` for compatibility reasons.
     """
+    replace_in_keys(data, "-", "_")
     data = deepcopy(data)
     try:
         instances = data["instances"]
