@@ -1,3 +1,5 @@
+import os
+
 from appdirs import user_cache_dir, user_config_dir
 
 
@@ -6,7 +8,11 @@ APPAUTHOR = "GitGuardian"
 
 
 def get_config_dir() -> str:
-    return user_config_dir(appname=APPNAME, appauthor=APPAUTHOR)
+    try:
+        # See tests/conftest.py for details
+        return os.environ["TEST_CONFIG_DIR"]
+    except KeyError:
+        return user_config_dir(appname=APPNAME, appauthor=APPAUTHOR)
 
 
 def get_cache_dir() -> str:
