@@ -18,10 +18,11 @@ class FilteredConfig:
         field_names = {field_.name for field_ in fields(cls)}
         filtered_fields = {}
         for key, item in data.items():
-            if key in field_names:
-                filtered_fields[key] = item
+            filtered_key = key.replace("-", "_")
+            if filtered_key in field_names:
+                filtered_fields[filtered_key] = item
             else:
-                display_warning("Unrecognized key in config: {}".format(key))
+                display_warning(f"Unrecognized key in config: {key}")
 
         return filtered_fields
 
