@@ -1,10 +1,9 @@
 from typing import Any, Dict, Optional
 
 from marshmallow import fields, post_dump
+from pygitguardian.iac_models import IaCFileResultSchema, IaCScanResultSchema
 from pygitguardian.models import BaseSchema, Match, MatchSchema
 
-from ggshield.iac.models import IaCFileResultSchema, IaCScanResultSchema
-
 
 class ExtendedMatchSchema(MatchSchema):
     pre_line_start = fields.Int(required=False, allow_none=True)
@@ -77,6 +76,7 @@ class FlattenedPolicyBreak(BaseSchema):
     validity = fields.String(required=False, allow_none=True)
     ignore_sha = fields.String(required=True)
     total_occurrences = fields.Integer(required=True)
+    known_secret = fields.Bool(required=False)
 
 
 class JSONResultSchema(BaseSchema):
@@ -110,10 +110,10 @@ class JSONScanCollectionSchema(BaseSchema):
     secrets_engine_version = fields.String(required=False)
 
 
-class IaCJSONFileResultSchema(IaCFileResultSchema):  # type: ignore
-    total_incidents = fields.Integer(default=0)
+class IaCJSONFileResultSchema(IaCFileResultSchema):
+    total_incidents = fields.Integer(dump_default=0)
 
 
-class IaCJSONScanResultSchema(IaCScanResultSchema):  # type: ignore
+class IaCJSONScanResultSchema(IaCScanResultSchema):
     entities_with_incidents = fields.List(fields.Nested(IaCJSONFileResultSchema))
-    total_incidents = fields.Integer(default=0)
+    total_incidents = fields.Integer(dump_default=0)
